#ifndef QUEST_GLOBAL
#define QUEST_GLOBAL

/* debugging, used in:
	-all error reports-
*/
#define VERBOSE_ERRORS		(0)

/* game version, used in:
	init_widgets()
*/
#define QUEST_WINDOW_TITLE 	"gQuest - 0.0.13"

/* game cycle delay time in milliseconds, used in:
	init_widgets()
*/
#define GAME_CYCLE_TIME		(5)

/* map dimensions, used in:
	Map.cell
   MAKE SURE THESE VALUES FIT IN 16 BITS!
*/
#define MAX_MAP_X		(256) 
#define MAX_MAP_Y		(256)

/* graphical variables, used in:
	-nothing yet-
*/
#define TILE_SIZE		(24)
#define XSPACES			(10)
#define YSPACES			(10)


/* space types, used in:
	Monster.access
	Space.type
*/
#define MOUNTAIN		(0x0001)
#define WATER			(0x0002)
#define GRASS			(0x0004)
#define DIRT			(0x0008)
#define STREET			(0x0010)
#define LAVA			(0x0020)
#define	ICE			(0x0040)
#define SAND			(0x0080)

/* directions, used in:
	Monster.facing
*/
#define UP			(0x0001)
#define UP_RIGHT		(0x0002)
#define RIGHT			(0x0004)
#define DOWN_RIGHT		(0x0008)
#define DOWN			(0x0010)
#define DOWN_LEFT		(0x0020)
#define LEFT			(0x0040)
#define UP_LEFT			(0x0080)

#define NORTH			(0x0001)
#define NORTH_EAST		(0x0002)
#define EAST			(0x0004)
#define SOUTH_EAST		(0x0008)
#define SOUTH			(0x0010)
#define SOUTH_WEST		(0x0020)
#define WEST			(0x0040)
#define NORTH_WEST		(0x0080)

/* pose types, used in:
	Monster.state
*/
#define LEFT_FOOT		(0x0001)
#define RIGHT_FOOT		(0x0002)
#define IDLE1			(0x0004)
#define IDLE2			(0x0008)
#define IDLE3			(0x0010)
#define IDLE4			(0x0020)

/* quality types, used in:
	Item.state
*/
#define BROKEN			(0x0001)
#define DAMAGED			(0x0002)
#define OK1			(0x0004)
#define OK2			(0x0008)
#define OK3			(0x0010)
#define OK4			(0x0020)

/* races, used in:
	Monster.race
*/
#define NEW_MONSTER		(0x0000)
#define	HUMAN			(0x0001)
#define ELF			(0x0002)
#define DWARF			(0x0004)
#define GNOME			(0x0008)
#define ORC			(0x0010)
#define GOBLIN			(0x0020)
#define KOBOLD			(0x0080)
#define OGRE			(0x0100)
#define WILD_ANIMAL		(0x0200)
#define DOMEST_ANIMAL		(0x0400)
#define GOOD_MONSTER		(0x0800)
#define NEUTRAL_MONSTER		(0x1000)
#define EVIL_MONSTER		(0x2000)

/* item kinds, used in:
	Item.kind
*/
#define NEW_ITEM		(0)
#define RUG			(1)
#define BOULDER			(2)
#define TREE			(3)
#define CAMPFIRE		(4)

/* monser properties, used in:
	Monster.properties
*/
#define IS_PLAYER		(0x0001)
#define IS_HOSTILE		(0x0002)
#define IS_SLEEPING		(0x0004)
#define IS_DEAD			(0x0008)
#define IS_DIZZY		(0x0010)

/* item properties, used in:
	Item.properties
*/
#define IS_MOVABLE		(0x0001)
#define IS_BASHABLE		(0x0002)
#define IS_STACKABLE		(0x0004)
#define IS_FLAMABLE		(0x0008)

/* x and y composition of directions, used in:
	-nothing yet-
*/
#define N_X			(0)
#define NE_X			(1)
#define E_X			(1)
#define SE_X			(1)
#define S_X			(0)
#define SW_X			(-1)
#define W_X			(-1)
#define NW_X			(-1)
#define N_Y			(-1)
#define NE_Y			(-1)
#define E_Y			(0)
#define SE_Y			(1)
#define S_Y			(1)
#define SW_Y			(1)
#define W_Y			(0)
#define NW_Y			(-1)

#define NORTH_X			(0)
#define NORTH_EAST_X		(1)
#define EAST_X			(1)
#define SOUTH_EAST_X		(1)
#define SOUTH_X			(0)
#define SOUTH_WEST_X		(-1)
#define WEST_X			(-1)
#define NORTH_WEST_X		(-1)
#define NORTH_Y			(-1)
#define NORTH_EAST_Y		(-1)
#define EAST_Y			(0)
#define SOUTH_EAST_Y		(1)
#define SOUTH_Y			(1)
#define SOUTH_WEST_Y		(1)
#define WEST_Y			(0)
#define NORTH_WEST_Y		(-1)

/* game control flags, used in:
	GameControl.game_state
*/
#define COMBAT_MODE		(0x0001)
#define TURN_DONE		(0x0002)
#define QUIT_GAME		(0x0004)

/* sprite id's, used in:
	IMAGE()
	PIXMAP()
	MASK()
*/
#define INTRO_SCREEN		(1)
#define QUEST_LOGO		(2)

/* quick image retriever, used in:
	wherever you need an image
*/
#define SPRITELIST		(gamec->sprites)
#define IMAGE(N)		(((Sprite*) g_list_nth_data(SPRITELIST,N))->image)
#define PIXMAP(N)		(((Sprite*) g_list_nth_data(SPRITELIST,N))->pixmap)
#define MASK(N)			(((Sprite*) g_list_nth_data(SPRITELIST,N))->mask)

/* future functions, used in:
	-wherever you need (gamec->cycle_cnt) + n-
*/
#define CYCLE_CNT		(gamec->cycle_cnt)
#define CYCLE_CNT_MAX		(256)
#define INCR_CYCLE(N)		((CYCLE_CNT+N)%CYCLE_CNT_MAX)

/* mask operators, used in:
	-wherever you set,clr,chk a mask-
*/
#define SET(M,B)		(M | B)
#define CLR(M,B)		(M & ~B)
#define CHK(M,B)		(((M & B) == 0) ? 0 : 1)

#endif /* QUEST_GLOBAL */
