#ifndef QUEST_TYPES
#define QUEST_TYPES

#include <gtk/gtk.h>
#include <gdk_imlib.h>
#include "global.h"

typedef gint16	direction;

typedef struct Sprite {

	GdkImlibImage	*image;
	GdkPixmap	*pixmap;
	GdkBitmap	*mask;

} Sprite;

typedef struct Item {

	/* Item ID */
	GString*	name;
	gint		id;

	/* coordinates */
	gint		x;
	gint		y;
	gint		width;
	gint		height;

	/* graphical information */
	guint16		state;
	GPtrArray*	sprites;
	gint		sprite_cnt;
	gint		sprite_cur;

	/* item information */
	guint16		properties;
	guint16		kind;
	guint16		access;
	gint		weight;
	
	/* battle information */
	gint		max_hp;
	gint		cur_hp;
	gint		armor; /* percentile */

	/* stacked items information */
	gint		inbag_cnt;
	gint16		inbag_mask;
	GPtrArray*	inbag;
	struct Item*	stacked; /* on the map */
	gint		where;	/* inventory location */
	struct Item*	inside;

} Item;

typedef struct Coords {

	gint 		x;
	gint 		y;

} Coords;

typedef struct Space {

	/* space information */
	gint16		properties;
	gint16		variation;
	gint16		access;
	
	/* what's on the space */
	GList*		mos;	/* monsters on space */
	GList*		ios;	/* items on space */

} Space;

typedef struct Map {

	/* Map ID */
	GString*	name;
	gint		id;

	/* the actual map */
	Space*		cell[MAX_MAP_X][MAX_MAP_Y];

	/* the update stack, Coords */
	GSList*		update;

	/* the location of the visible area on the map */
	gint16		area_ox;
	gint16		area_oy;

} Map;

typedef struct Attack {

	gint		tohit;
	gint		min_dmg;
	gint		max_dmg;
	gint		ap_cost;

} Attack;

typedef struct Monster {
	
	/* Monster ID */
	GString*	name;
	gint		id;

	/* coordinates and planned path */
	gint		x;
	gint		y;
	gint		width;
	gint		height;
	GArray*		path;

	/* graphical information */
	guint16		facing;
	guint16		state;
	GPtrArray*	sprites;
	gint		sprite_cnt;
	gint		sprite_cur;

	/* character information */
	guint16		properties;
	guint16		race;
	guint16		access;	
	guint		agression; /* percentile */
	gint		weight;

	/* behaviour */
	void	 	(*behaviour)(); 
	GArray*		memory;
	guint		memory_cnt;

	/* battle infomation */
	gint		max_ap;
	gint		cur_ap;
	gint		max_hp;
	gint		cur_hp;
	guint		armor; /* percentile */
	GPtrArray*	attacks;
	gint		attack_cnt;
	gint		attack_cur; 
	guint		initiative; /* percentile */
	guint		initiative_adj; /* percentile */

	/* inventory */
	GPtrArray*	inventory;
	guint16		inventory_mask;

} Monster;

typedef struct GameControl {

	Map*		map;
	GList*		image_files;
	GList*		sprites;
	GList*		monsters;
	GList*		items;
	gint32		turn;
	gint16		game_state;
	guint8		cycle_cnt;

} GameControl;

#endif /* QUEST_TYPES */